package com.webinstats.webinstats;

import android.content.Context;
import android.widget.Toast;

import androidx.annotation.NonNull;

import java.util.HashMap;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import webinstats.android_wis.Webinstats;

/**
 * WebinstatsPlugin
 */
public class WebinstatsPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

    private MethodChannel channel;
    private Context context;
    private Webinstats webinstats = null;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "webinstats");
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        context = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    }

    @Override
    public void onDetachedFromActivity() {
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        switch (call.method) {
            case "addItem":
                addItem(call.arguments());
                break;
            case "execute":
                execute(call);
                break;
            case "createEvent":
                createNewEvent(call);
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    private void execute(@NonNull MethodCall call) {
        if (webinstats == null) {
            initializeWebinstats(call.arguments());
        }

        webinstats.execute(context, call.arguments());
    }

    private void createNewEvent(@NonNull MethodCall call) {
        if (webinstats == null) {
            initializeWebinstats(call.arguments());
        }
        webinstats.createEvent(call.argument("eventName"));
    }

    private void initializeWebinstats(Map<String, Object> arg) {
        String domain = String.valueOf(arg.get("domain"));
        String companyId = String.valueOf(arg.get("companyId"));
        webinstats = new Webinstats(domain, companyId, "0");
    }

    private void addItem(Map<String, Object> arguments) {
        String productId = String.valueOf(arguments.get("productId"));
        String productQuantity = String.valueOf(arguments.get("quantity"));
        String productPrice = String.valueOf(arguments.get("price"));
        String productTitle = String.valueOf(arguments.get("title"));
        String category = String.valueOf(arguments.get("category"));

        if (webinstats == null) {
            initializeWebinstats(arguments);
        }

        boolean isItemAdded = webinstats.addItem(
                productId,
                productQuantity,
                productPrice,
                category,
                productTitle);
        if (!isItemAdded) {
            Toast.makeText(context, "Unable to add Item.", Toast.LENGTH_SHORT).show();
        }
    }

}
